/*
 *  unrestrict.c: Remove restricted mode from a connected client.
 *
 *  Copyright 2004 by W. Campbell
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are
 *  met:
 *
 *  1.Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  2.Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *  3.The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 *  IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 *  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *  DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
 *  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 *  (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 *  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 *  STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 *  IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *
 *  $Id: unrestrict.c,v 1.1.2.2 2004/11/08 01:49:47 nenolod Exp $
 */

#include "stdinc.h"
#include "tools.h"
#include "client.h"
#include "ircd.h"
#include "hash.h"
#include "numeric.h"
#include "send.h"
#include "msg.h"
#include "parse.h"
#include "modules.h"
#include "handlers.h"

static void mo_unrestrict(struct Client *, struct Client *, int, char **);

struct Message unrestrict_msgtab = {
	"UNRESTRICT", 0, 0, 2, 0, MFLG_SLOW, 0,
	{m_unregistered, m_not_oper, m_ignore, mo_unrestrict, m_ignore}
};

#ifndef STATIC_MODULES
void
_modinit(void)
{
	mod_add_cmd(&unrestrict_msgtab);
}

void
_moddeinit(void)
{
	mod_del_cmd(&unrestrict_msgtab);
}

char *_version = "$Revision: 1.1.2.2 $";
#endif

/*
 * mo_unrestrict - Remove a restricted mode from a connected local
 *                 client.
 */
static void
mo_unrestrict(struct Client *client_p, struct Client *source_p, int parc, char *parv[])
{
	struct Client *target_p;

	target_p = find_client(parv[1]);

	if (target_p == NULL)
	{
		sendto_one(source_p, form_str(ERR_NOSUCHNICK), me.name, source_p->name,
				parv[1]);
		return;
	}

	if (!MyClient(target_p))
	{
		sendto_one(source_p, ":%s NOTICE %s :Cannot unrestrict remote client %s.",
			   me.name, source_p->name, parv[1]);
		return;
	}

	if (!IsRestricted(target_p))
	{
		sendto_one(source_p, ":%s NOTICE %s :Client %s is not restricted.",
			   me.name, source_p->name, parv[1]);
		return;
	}

	ClearRestricted(target_p);
	sendto_one(source_p, ":%s NOTICE %s :Client %s is now unrestricted.",
		   me.name, source_p->name, parv[1]);
	sendto_one(target_p, ":%s NOTICE %s :You are now unrestricted.",
		   me.name, source_p->name);
	sendto_realops_flags(UMODE_SERVNOTICE, L_ALL,
			     "Client %s is now unrestricted.", parv[1]);

	return;
}
